@@ -22,8 +22,10 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
 
         this.mount = mount;
 
-        let ejectIcon = new St.Icon({ icon_name: 'media-eject-symbolic',
-                                      style_class: 'popup-menu-icon ' });
+        let ejectIcon = new St.Icon({
+            icon_name: 'media-eject-symbolic',
+            style_class: 'popup-menu-icon'
+        });
         let ejectButton = new St.Button({ child: ejectIcon });
         ejectButton.connect('clicked', this._eject.bind(this));
         this.actor.add(ejectButton);
@@ -63,18 +65,18 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 
     _eject() {
-        let mountOp = new ShellMountOperation.ShellMountOperation(this.mount);
+        let unmountArgs = [
+            Gio.MountUnmountFlags.NONE,
+            (new ShellMountOperation.ShellMountOperation(this.mount)).mountOp,
+            null // Gio.Cancellable
+        ];
 
         if (this.mount.can_eject())
-            this.mount.eject_with_operation(Gio.MountUnmountFlags.NONE,
-                                            mountOp.mountOp,
-                                            null, // Gio.Cancellable
-                                            this._ejectFinish.bind(this));
+            this.mount.eject_with_operation(...unmountArgs,
+                this._ejectFinish.bind(this));
         else
-            this.mount.unmount_with_operation(Gio.MountUnmountFlags.NONE,
-                                              mountOp.mountOp,
-                                              null, // Gio.Cancellable
-                                              this._unmountFinish.bind(this));
+            this.mount.unmount_with_operation(...unmountArgs,
+                this._unmountFinish.bind(this));
     }
 
     _unmountFinish(mount, result) {
@@ -95,14 +97,14 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
 
     _reportFailure(exception) {
         // TRANSLATORS: %s is the filesystem name
-        let msg = _("Ejecting drive “%s” failed:").format(this.mount.get_name());
+        let msg = _('Ejecting drive “%s” failed:').format(this.mount.get_name());
         Main.notifyError(msg, exception.message);
     }
 
     activate(event) {
+        let uri = this.mount.get_root().get_uri();
         let context = global.create_app_launch_context(event.get_time(), -1);
-        Gio.AppInfo.launch_default_for_uri(this.mount.get_root().get_uri(),
-                                           context);
+        Gio.AppInfo.launch_default_for_uri(uri, context);
 
         super.activate(event);
     }
@@ -111,11 +113,13 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
 let DriveMenu = GObject.registerClass(
 class DriveMenu extends PanelMenu.Button {
     _init() {
-        super._init(0.0, _("Removable devices"));
+        super._init(0.0, _('Removable devices'));
 
         let hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
-        let icon = new St.Icon({ icon_name: 'media-eject-symbolic',
-                                 style_class: 'system-status-icon' });
+        let icon = new St.Icon({
+            icon_name: 'media-eject-symbolic',
+            style_class: 'system-status-icon'
+        });
 
         hbox.add_child(icon);
         hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
@@ -136,7 +140,7 @@ class DriveMenu extends PanelMenu.Button {
         this._monitor.get_mounts().forEach(this._addMount.bind(this));
 
         this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
-        this.menu.addAction(_("Open Files"), event => {
+        this.menu.addAction(_('Open Files'), event => {
             let appSystem = Shell.AppSystem.get_default();
             let app = appSystem.lookup_app('org.gnome.Nautilus.desktop');
             app.activate_full(-1, event.get_time());
