@@ -38,65 +38,54 @@ class PlaceInfo {
         return false;
     }
 
-    _createLaunchCallback(launchContext, tryMount) {
-        return (_ignored, result) => {
-            try {
-                Gio.AppInfo.launch_default_for_uri_finish(result);
-            } catch (e) {
-                if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_MOUNTED)) {
-                    let source = {
-                        get_icon: () => { return this.icon; }
-                    };
-                    let op = new ShellMountOperation.ShellMountOperation(source);
-                    this.file.mount_enclosing_volume(0, op.mountOp, null, (file, result) => {
-                        try {
-                            op.close();
-                            file.mount_enclosing_volume_finish(result);
-                        } catch (e) {
-                            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.FAILED_HANDLED))
-                                // e.g. user canceled the password dialog
-                                return;
-                            Main.notifyError(_("Failed to mount volume for “%s”").format(this.name), e.message);
-                            return;
-                        }
-
-                        if (tryMount) {
-                            let callback = this._createLaunchCallback(launchContext, false);
-                            Gio.AppInfo.launch_default_for_uri_async(file.get_uri(),
-                                                                     launchContext,
-                                                                     null,
-                                                                     callback);
-                        }
-                    });
-                } else {
-                    Main.notifyError(_("Failed to launch “%s”").format(this.name), e.message);
-                }
+    async _ensureMountAndLaunch(context, tryMount) {
+        try {
+            await this._launchDefaultForUri(this.file.get_uri(), context, null);
+        } catch (e) {
+            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_MOUNTED)) {
+                Main.notifyError(_('Failed to launch “%s”').format(this.name), e.message);
+                return;
             }
-        };
+
+            let source = {
+                get_icon: () => this.icon
+            };
+            let op = new ShellMountOperation.ShellMountOperation(source);
+            try {
+                await this._mountEnclosingVolume(0, op.mountOp, null);
+
+                if (tryMount)
+                    this._ensureMountAndLaunch(context, false);
+            } catch (e) {
+                if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.FAILED_HANDLED))
+                    Main.notifyError(_('Failed to mount volume for “%s”').format(this.name), e.message);
+            } finally {
+                op.close();
+            }
+        }
     }
 
     launch(timestamp) {
         let launchContext = global.create_app_launch_context(timestamp, -1);
-        let callback = this._createLaunchCallback(launchContext, true);
-        Gio.AppInfo.launch_default_for_uri_async(this.file.get_uri(),
-                                                 launchContext,
-                                                 null,
-                                                 callback);
+        this._ensureMountAndLaunch(launchContext, true);
     }
 
     getIcon() {
-        this.file.query_info_async('standard::symbolic-icon', 0, 0, null,
-                                   (file, result) => {
-                                       try {
-                                           let info = file.query_info_finish(result);
-                                           this.icon = info.get_symbolic_icon();
-                                           this.emit('changed');
-                                       } catch (e) {
-                                           if (e instanceof Gio.IOErrorEnum)
-                                               return;
-                                           throw e;
-                                       }
-                                   });
+        this.file.query_info_async('standard::symbolic-icon',
+            Gio.FileQueryInfoFlags.NONE,
+            0,
+            null,
+            (file, result) => {
+                try {
+                    let info = file.query_info_finish(result);
+                    this.icon = info.get_symbolic_icon();
+                    this.emit('changed');
+                } catch (e) {
+                    if (e instanceof Gio.IOErrorEnum)
+                        return;
+                    throw e;
+                }
+            });
 
         // return a generic icon for this kind for now, until we have the
         // icon from the query info above
@@ -125,12 +114,38 @@ class PlaceInfo {
             throw e;
         }
     }
+
+    _launchDefaultForUri(uri, context, cancel) {
+        return new Promise((resolve, reject) => {
+            Gio.AppInfo.launch_default_for_uri_async(uri, context, cancel, (o, res) => {
+                try {
+                    Gio.AppInfo.launch_default_for_uri_finish(res);
+                    resolve();
+                } catch (e) {
+                    reject(e);
+                }
+            });
+        });
+    }
+
+    _mountEnclosingVolume(flags, mountOp, cancel) {
+        return new Promise((resolve, reject) => {
+            this.file.mount_enclosing_volume(flags, mountOp, cancel, (o, res) => {
+                try {
+                    this.file.mount_enclosing_volume_finish(res);
+                    resolve();
+                } catch (e) {
+                    reject(e);
+                }
+            });
+        });
+    }
 }
 Signals.addSignalMethods(PlaceInfo.prototype);
 
 class RootInfo extends PlaceInfo {
     _init() {
-        super._init('devices', Gio.File.new_for_path('/'), _("Computer"));
+        super._init('devices', Gio.File.new_for_path('/'), _('Computer'));
 
         let busName = 'org.freedesktop.hostname1';
         let objPath = '/org/freedesktop/hostname1';
@@ -140,7 +155,7 @@ class RootInfo extends PlaceInfo {
 
             this._proxy = obj;
             this._proxy.connect('g-properties-changed',
-                                this._propertiesChanged.bind(this));
+                this._propertiesChanged.bind(this));
             this._propertiesChanged(obj);
         });
     }
@@ -153,7 +168,7 @@ class RootInfo extends PlaceInfo {
         // GDBusProxy will emit a g-properties-changed when hostname1 goes down
         // ignore it
         if (proxy.g_name_owner) {
-            this.name = proxy.PrettyHostname || _("Computer");
+            this.name = proxy.PrettyHostname || _('Computer');
             this.emit('changed');
         }
     }
@@ -183,18 +198,18 @@ class PlaceDeviceInfo extends PlaceInfo {
     }
 
     eject() {
-        let mountOp = new ShellMountOperation.ShellMountOperation(this._mount);
+        let unmountArgs = [
+            Gio.MountUnmountFlags.NONE,
+            (new ShellMountOperation.ShellMountOperation(this._mount)).mountOp,
+            null // Gio.Cancellable
+        ];
 
         if (this._mount.can_eject())
-            this._mount.eject_with_operation(Gio.MountUnmountFlags.NONE,
-                                             mountOp.mountOp,
-                                             null, // Gio.Cancellable
-                                             this._ejectFinish.bind(this));
+            this._mount.eject_with_operation(...unmountArgs,
+                this._ejectFinish.bind(this));
         else
-            this._mount.unmount_with_operation(Gio.MountUnmountFlags.NONE,
-                                               mountOp.mountOp,
-                                               null, // Gio.Cancellable
-                                               this._unmountFinish.bind(this));
+            this._mount.unmount_with_operation(...unmountArgs,
+                this._unmountFinish.bind(this));
     }
 
     _ejectFinish(mount, result) {
@@ -214,7 +229,7 @@ class PlaceDeviceInfo extends PlaceInfo {
     }
 
     _reportFailure(exception) {
-        let msg = _("Ejecting drive “%s” failed:").format(this._mount.get_name());
+        let msg = _('Ejecting drive “%s” failed:').format(this._mount.get_name());
         Main.notifyError(msg, exception.message);
     }
 }
@@ -263,9 +278,8 @@ var PlacesManager = class {
         };
 
         this._settings = new Gio.Settings({ schema_id: BACKGROUND_SCHEMA });
-        this._showDesktopIconsChangedId =
-            this._settings.connect('changed::show-desktop-icons',
-                                   this._updateSpecials.bind(this));
+        this._showDesktopIconsChangedId = this._settings.connect(
+            'changed::show-desktop-icons', this._updateSpecials.bind(this));
         this._updateSpecials();
 
         /*
@@ -298,9 +312,17 @@ var PlacesManager = class {
     }
 
     _connectVolumeMonitorSignals() {
-        const signals = ['volume-added', 'volume-removed', 'volume-changed',
-                         'mount-added', 'mount-removed', 'mount-changed',
-                         'drive-connected', 'drive-disconnected', 'drive-changed'];
+        const signals = [
+            'volume-added',
+            'volume-removed',
+            'volume-changed',
+            'mount-added',
+            'mount-removed',
+            'mount-changed',
+            'drive-connected',
+            'drive-disconnected',
+            'drive-changed'
+        ];
 
         this._volumeMonitorSignals = [];
         let func = this._updateMounts.bind(this);
@@ -325,14 +347,15 @@ var PlacesManager = class {
     }
 
     _updateSpecials() {
-        this._places.special.forEach(p => { p.destroy(); });
+        this._places.special.forEach(p => p.destroy());
         this._places.special = [];
 
         let homePath = GLib.get_home_dir();
 
-        this._places.special.push(new PlaceInfo('special',
-                                                Gio.File.new_for_path(homePath),
-                                                _("Home")));
+        this._places.special.push(new PlaceInfo(
+            'special',
+            Gio.File.new_for_path(homePath),
+            _('Home')));
 
         let specials = [];
         let dirs = DEFAULT_DIRECTORIES.slice();
@@ -367,17 +390,18 @@ var PlacesManager = class {
         let networkMounts = [];
         let networkVolumes = [];
 
-        this._places.devices.forEach(p => { p.destroy(); });
+        this._places.devices.forEach(p => p.destroy());
         this._places.devices = [];
-        this._places.network.forEach(p => { p.destroy(); });
+        this._places.network.forEach(p => p.destroy());
         this._places.network = [];
 
         /* Add standard places */
         this._places.devices.push(new RootInfo());
-        this._places.network.push(new PlaceInfo('network',
-                                                Gio.File.new_for_uri('network:///'),
-                                                _("Browse Network"),
-                                                'network-workgroup-symbolic'));
+        this._places.network.push(new PlaceInfo(
+            'network',
+            Gio.File.new_for_uri('network:///'),
+            _('Browse Network'),
+            'network-workgroup-symbolic'));
 
         /* first go through all connected drives */
         let drives = this._volumeMonitor.get_connected_drives();
